14.62. cdist-type__install_reboot(7) — cdist 4.8.1 documentation

# 14.62. cdist-type__install_reboot(7)

## 14.62.1. NAME

cdist-type__install_reboot - run reboot

## 14.62.2. DESCRIPTION

This cdist type allows you to reboot a machine.

## 14.62.3. REQUIRED PARAMETERS

None

## 14.62.4. OPTIONAL PARAMETERS

options
  options to pass to the reboot command. e.g. -f

## 14.62.5. EXAMPLES

    __install_reboot

## 14.62.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 14.62.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.